export declare const noOpTag: (strings: TemplateStringsArray, ...exps: string[]) => string;
export declare const gql: (strings: TemplateStringsArray, ...exps: string[]) => string;
export declare type Fetch = (url: RequestInfo, init?: RequestInit) => Promise<Response>;
export declare type ApiOptions = {
    wsUrl?: string;
    headers?: object;
    fetch?: Fetch;
    onResponse?: (response: GraphQLResponse) => any;
};
export declare type Subscription = {
    onData: (handler: SubscriptionDataHandler) => Subscription;
    close: () => void;
};
export declare type SubscriptionDataHandler = (data: any) => any;
export declare type GraphQLResponse<T = any> = Response & {
    condition: GraphQLResponseCondition;
    data?: T;
    graphQLErrors?: GraphQLError[];
    error?: Error;
    query?: string;
    variables?: any;
};
export declare enum GraphQLResponseCondition {
    OK = "OK",
    InvalidRequest = "Invalid request",
    NetworkCallFailed = "Network call failed",
    InvalidResponse = "Invalid response",
    RequestError = "Request error",
    FieldError = "Field error"
}
export declare type GraphQLError = {
    message: string;
    locations?: Array<{
        line: number;
        column: number;
    }>;
    path?: string[];
    extensions?: unknown;
};
export declare class Api {
    url: string;
    wsUrl: string;
    fetch: Fetch;
    headers: any;
    socket: Socket;
    onReponse: (response: GraphQLResponse) => any;
    constructor(url: string, apiOptions?: string | ApiOptions);
    get log(): (msg: string) => void;
    set log(fn: (msg: string) => void);
    run<T = any>(query: string, variables?: any): Promise<GraphQLResponse<T>>;
    subscribe(query: string, variables?: object, channelName?: string): Subscription;
}
export declare type SocketSubscription = {
    dataHandler?: (data: any) => any;
};
declare class Socket {
    log: (msg: string) => void;
    webSocket: WebSocket;
    subscriptions: {
        [id: string]: SocketSubscription;
    };
    connected: boolean;
    connectedHandlers: Array<() => void>;
    constructor(wsUrl: string, headers?: object, onConnected?: () => void);
}
export declare type InputTypeInfo = {
    name: string;
    fields: InputFieldInfo[];
};
export declare type InputFieldInfo = {
    name: string;
    typeName: string;
    isList: boolean;
    isNonNull: boolean;
};
export declare type InputTypeInfoMap = {
    [typeName: string]: InputTypeInfo;
};
export declare const trimInput: <T>(proposedInput: T, typeName: string, inputTypeInfoMap: InputTypeInfoMap) => T;
export {};
